#!/usr/bin/perl

if (!@ARGV) { die "Usage: $0 filename\n"; }
my ($InFolder,$pathToTCXFolder) = @ARGV;
opendir(DIR, $InFolder);
@ListOfFiles = readdir(DIR); 
closedir(DIR);
foreach $currentFile(@ListOfFiles){
	if (substr($currentFile,-4)=~m/\.tcx/i){
		$fullName = $InFolder . $currentFile;
		#print "$fullName\n";
		$TCXCheck = "$pathToTCXFolder/" . $currentFile;
		if (!-e $TCXCheck){
			$Something = "Y";
			&ParseLogbook($fullName,$TCXCheck);
		}
	}
}
if (!$Something){
	print "NOTHING";
}



################################################################################
sub ParseLogbook {
	# Parse a Garmin Logbook XML file, and split into separate files for each track
	
	# Algorithm:
	#   1. read xml file
	#   2. every time a 'run boundary' is crossed, write it to a file with the syntax:
	#      date-time[-note].{xml|hst}
	
	my ($infile,$TCXCheck) = @_;
	my (@forerunner_file,$run,$file_header,$inHeader,$filename,$notes,$filename_note,$gpx_trackname,%output);
	
	my $note_chars = ($^O =~ /^Mac/) ? 11 : 40;
	my $model = '201';
	my %file_footer;
	$file_footer{'201'} = "</History>\n";
	$file_footer{'301'} = "</HistoryDatabase>\n";
	$file_footer{'305'} = "  </History>\n</TrainingCenterDatabase>\n";
	$file_footer{'2007'} = "</TrainingCenterDatabase>\n";
	$file_footer{'gpx'} = "</gpx>\n";
	
	open(MASTERXML,$infile) || die "Cannot open $infile\n";  # open master file for reading
	foreach (<MASTERXML>) {
		$_ =~ s/(?<=\>)(<\w[^>]*>)/\n$1/g; # put tags on separate lines
		$_ =~ s/(<\/\w[^>]*>)(<\/\w[^>]*>)/$1\n$2/g; # put closing tags on separate lines
		$_ =~ s/(<\/\w[^>]*>)(<\/\w[^>]*>)/$1\n$2/g; # put closing tags on separate lines (once more for good measure)
		push (@forerunner_file,split(/[\r\n]+/,$_)); # fix some line break issues
	}
	close (MASTERXML);
	
	
	foreach (@forerunner_file[0..4]) {
		if (/<HistoryDatabase/i) { $model = '301'; } # This is a Forerunner 301 file
		elsif (/xmlschemas\/TrainingCenterDatabase\/v1/i) { $model = '305'; } # This is a Forerunner 305 file
		elsif (/xmlschemas\/TrainingCenterDatabase\/v2/i) { $model = '2007'; } # This is a 2007 GTC file (.tcx)
		elsif (/<gpx/i) { $model = 'gpx'; } # This is a GPX file
	}
	
	if ($model eq '2007') {
		$theRegisteredActivity = "";
		$theStartTime = "";
		$totalDistance = 0;
		foreach my $line (@forerunner_file) {
			$line =~ s/^\xEF[\xBA-\xBF]*//; # remove Unicode marker, if present
			if ($line =~ /<Activity Sport/i) {
				if (!$theRegisteredActivity){
					$theRegisteredActivity = (split('\"',$line))[1];
				}else{
					print "$theRegisteredActivity||$theStartTime||";
					print sprintf("%.2f", $totalDistance);
					print "||$TCXCheck??";
					$theStartTime = "";
					$totalDistance = 0;
					$theRegisteredActivity = (split('\"',$line))[1];
				}
			}
			if ($line =~ /<Lap StartTime/i) {
				if (!$theStartTime){
					$theStartTime = (split('\"',$line))[1];
				}
				$newLap = "Y";
			}
			if (($line =~ /<DistanceMeters/i)&&($newLap eq "Y")) {
				$currentDistance = (split('\>',$line))[1];
				$currentDistance = (split('\<',$currentDistance))[0];
				$currentDistance = (($currentDistance/1000) * 0.621371192);
				$totalDistance += $currentDistance;
				$newLap = "N";
			}
			
		}
	}
	print "$theRegisteredActivity||$theStartTime||";
	print sprintf("%.2f", $totalDistance);
	print "||$TCXCheck??";
}